log using inlf_0214.log, replace
/************************************************/
/* LFP Regressions with March CPS (2002-2014)   */
/* Coile, Duggan, Guo							*/
/* January 10, 2015 							*/
/************************************************/
clear all
set more off
set matsize 5000

use cpsmaster.dta, clear

/*For all regressions, we weight by a_fnlwgt, the Basic(Final) Person Weight. 
It is equal to zero for populations not sampled in the other monthly surveys 
(Armed forces, Hispanic oversample) */

// Base
local reg0214 vet black other hispanic yearDV23-yearDV34

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', replace keep (vet black other hispanic) ctitle (m1,base)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m2,base)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m3,base)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m4,base)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m5,base)
}

// State FEs 
local reg0214 vet black other hispanic yearDV23-yearDV34 year23state* year24state* year25state* year26state* year27state* year28state* year29state* year30state* year31state* year32state* year33state* year34state* year35state*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m1,stateFE)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m2,stateFE)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m3,stateFE)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m4,stateFE)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m5,stateFE)
}

// State UR
gen vet_stateur = vet*demeanedstur

local reg0214 vet black other hispanic vet_stateur yearDV23-yearDV34 year23state* year24state* year25state* year26state* year27state* year28state* year29state* year30state* year31state* year32state* year33state* year34state* year35state*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m1,stateUR)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m2,stateUR)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m3,stateUR)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m4,stateUR)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m5,stateUR)
}

// Add State x Vet FEs

local reg0214 vet black other hispanic vet_stateur statevet* statenovet* yearDV23-yearDV34 year23state* year24state* year25state* year26state* year27state* year28state* year29state* year30state* year31state* year32state* year33state* year34state* year35state*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m1,statevet)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m2,statevet)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m3,statevet)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m4,statevet)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m5,statevet)
}

// Lagged State UR
gen vet_stateur_1 = vet*demeanedstur_1

local reg0214 vet black other hispanic vet_stateur_1 yearDV23-yearDV34 year23state* year24state* year25state* year26state* year27state* year28state* year29state* year30state* year31state* year32state* year33state* year34state* year35state*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m1,lagstUR)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m2,lagstUR)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m3,lagstUR)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m4,lagstUR)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m5,lagstUR)
}

// Lagged State x Vet FEs
local reg0214 vet black other hispanic vet_stateur_1 statevet* statenovet* yearDV23-yearDV34 year23state* year24state* year25state* year26state* year27state* year28state* year29state* year30state* year31state* year32state* year33state* year34state* year35state*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m1,lagstvet)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m2,lagstvet)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m3,lagstvet)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m4,lagstvet)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m5,lagstvet)
}

// County FEs

local reg0214 vet black other hispanic yearDV23-yearDV34 ageDV*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m1,countyFE)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m2,countyFE)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m3,countyFE)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m4,countyFE)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m5,countyFE)
}

// County UR
gen vet_countyur = vet*demeanedur

local reg0214 vet black other hispanic vet_countyur yearDV23-yearDV34 ageDV*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m1,countyUR)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m2,countyUR)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m3,countyUR)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m4,countyUR)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m5,countyUR)
}

// Add County x Vet FEs

local reg0214 vet black other hispanic vet_countyur fipsvet* fipsnovet* yearDV23-yearDV34 ageDV* 

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m1,countyvet)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m2,countyvet)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m3,countyvet)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m4,countyvet)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2013 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur black other hispanic) ctitle (m5,countyvet)
}

// Lagged County UR
gen vet_countyur_1 = vet*demeanedur_1

local reg0214 vet black other hispanic vet_countyur_1 yearDV23-yearDV34 ageDV*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m1,lagctyUR)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m2,lagctyUR)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m3,lagctyUR)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m4,lagctyUR)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m5,lagctyUR)
}

// Lagged County x Vet FEs
local reg0214 vet black other hispanic vet_countyur_1 yearDV23-yearDV34 ageDV* fipsvet* fipsnovet*

foreach x of varlist inlf {
local outreg reg_`x'_0214.xls
areg `x' `reg0214' if a_age>=25 & a_age<=34 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m1,lagctyvet)
areg `x' `reg0214' if a_age>=35 & a_age<=54 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m2,lagctyvet)
areg `x' `reg0214' if a_age>=55 & a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m3,lagctyvet)
areg `x' `reg0214' if a_age>=65 & a_age<=74 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m4,lagctyvet)
areg `x' `reg0214' if a_age<=64 & year>=2002 & year<=2014 [aw=a_fnlwgt], a(fipsyear) cluster(fips)
outreg2 using `outreg', keep (vet vet_countyur_1 black other hispanic) ctitle (m5,lagctyvet)
}

log close
